BmffMerkleProof class final

Per-fragment proof stored in a C2PA merkle UUID box.

Constructors

BmffMerkleProof({required int uniqueId, required int localId, required int location, Iterable<List<int>>? hashes})
Creates a per-fragment Merkle proof.
BmffMerkleProof.fromCbor(Object? value)
Decodes a per-fragment Merkle proof from a CBOR map.
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
hashes → List<Uint8List>?
Sibling hashes from leaf toward the anchored Merkle row.
final
localId → int
Local identifier that must match the MerkleMap.
final
location → int
Zero-based fragment index proven by this proof.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uniqueId → int
Assertion-level identifier that must match the MerkleMap.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCborMap() → Map<String, Object?>
Encodes this proof using BMFF merkle UUID box CBOR keys.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override