C2paArchiveLoadOptions class final
Options used when loading a C2PA builder archive.
Constructors
- C2paArchiveLoadOptions({C2paArchiveResourceResolver? resourceResolver})
-
Creates archive load options.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- resourceResolver → C2paArchiveResourceResolver?
-
Resolver for external resources, or
nullto reject them.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited