C2paManifestCompression enum
Compression state for a C2PA manifest store entry.
Values
- none → const C2paManifestCompression
-
Manifest bytes are stored uncompressed.
- brotli → const C2paManifestCompression
-
Manifest bytes use Brotli compression.
- invalid → const C2paManifestCompression
-
Compression metadata is malformed or unsupported.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
C2paManifestCompression> - A constant List of the values in this enum, in order of their declaration.