C2paRemoteTransportException class final

Exception thrown when a remote manifest transport fails.

Inheritance

Constructors

C2paRemoteTransportException(String message, {required C2paRemoteTransportFailure failure, required Uri uri, Object? cause, StackTrace? stackTrace})
Creates a categorized transport exception for uri.
const

Properties

cause → Object?
Lower-level error that caused this exception, or null if none exists.
finalinherited
failure → C2paRemoteTransportFailure
Machine-readable reason for the transport failure.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
Human-readable description of the failure condition.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
Stack trace associated with cause, or null when unavailable.
finalinherited
uri → Uri
URI being fetched when the transport failure occurred.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited