CawgIcaCompatibility enum

Selects stable CAWG 1.1 behavior or c2pa-rs 0.90.22 compatibility.

Inheritance
Available extensions

Values

stable11 → const CawgIcaCompatibility

Applies the stable CAWG 1.1 identity-claims aggregation rules.

c2paRs09022 → const CawgIcaCompatibility

Applies compatibility behavior used by c2pa-rs 0.90.22.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CawgIcaCompatibility>
A constant List of the values in this enum, in order of their declaration.