CawgIdentityValidator class final

Validator for CAWG identity assertions referenced by a claim.

Constructors

CawgIdentityValidator()
Creates a stateless CAWG identity validator.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate({required String assertionLabel, required CawgIdentityAssertion assertion, required Iterable<ClaimHashedUri> claimAssertions, required C2paContext context, Map<String, CawgIdentityAssertion> identityAssertions = const {}}) → Future<CawgIdentityValidationResult>
Validates identity references, hard binding, and signature trust.

Operators

operator ==(Object other) → bool
The equality operator.
inherited