ValidationState enum
Overall validation state for an active manifest and its ingredients.
Values
- invalid → const ValidationState
-
Required C2PA signature validation checks failed or are missing.
- valid → const ValidationState
-
Required C2PA signature checks passed, but trust was not established.
- trusted → const ValidationState
-
Required C2PA signature checks passed with trusted signing credentials.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ValidationState> - A constant List of the values in this enum, in order of their declaration.