C2paArchiveException class base
Exception thrown when a C2PA working archive cannot be processed.
This is used for malformed archives, unsafe archive paths, and resource failures while importing or exporting archive contents.
- Inheritance
-
- Object
- C2paException
- C2paArchiveException
- Implementers
Constructors
- C2paArchiveException(String message, {Object? cause, StackTrace? stackTrace})
-
Creates an archive exception for working-archive handling failure.
const
Properties
- cause → Object?
-
Lower-level error that caused this exception, or
nullif none exists.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description of the failure condition.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace associated with cause, or
nullwhen unavailable.finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited