C2paResourceNotFoundException class final
Exception thrown when a normalized resource URI has no stored bytes.
- Inheritance
-
- Object
- C2paException
- C2paResourceException
- C2paResourceNotFoundException
Constructors
- C2paResourceNotFoundException(String uri)
-
Creates a not-found exception for normalized
uri.const
Properties
- cause → Object?
-
Lower-level error that caused this exception, or
nullif none exists.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description of the failure condition.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace associated with cause, or
nullwhen unavailable.finalinherited - uri → String
-
Normalized resource URI that was not found.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited